@@ -18,13 +18,13 @@ expect_true(.is_valid_leaf(tree = tree, leaf = "a"))
 expect_error(.is_valid_leaf(tree = tree, leaf = "a1"))
 
 # print/display method
-expect_is(
-  hier_display(tree), c("cli_tree", "tree")
+expect_identical(
+  hier_display(tree), NULL
 )
 
 # print, but start from a subnode
-expect_is(
-  hier_display(tree, root = "b"), c("cli_tree", "tree")
+expect_identical(
+  hier_display(tree, root = "b"), NULL
 )
 
 # export
@@ -93,7 +93,7 @@ expect_null(erg_sdc$bogus$bogus_codes)
 expect_null(erg_sdc$bogus$bogus_parents)
 
 erg_code <- hier_convert(tree, as = "code")
-expect_is(hier_display(erg_code), c("cli_tree", "tree"))
+expect_identical(hier_display(erg_code), NULL)
 
 expect_is(erg_code, "character")
 expect_identical(length(erg_code), 3L)
